Class: Coradoc::Html::Converters::BlockImage
- Defined in:
- lib/coradoc/html/converters/block_image.rb
Overview
Converter for CoreModel::Image (block image)
Class Method Summary collapse
Methods inherited from Base
build_class_attribute, build_element, build_html_attributes, convert_content_to_html, convert_element_to_core, convert_node_to_core, escape_attribute, escape_html, extract_model_attributes, extract_node_attributes, extract_text_fallback, find_converter_class_by_name, find_converter_for_model, handle_unknown_content, render_core_abbreviation, render_core_annotation_block, render_core_bibliography, render_core_bibliography_entry, render_core_block, render_core_block_image, render_core_definition_item, render_core_definition_list, render_core_footnote, render_core_footnote_reference, render_core_inline_element, render_core_inline_image, render_core_list_block, render_core_list_item, render_core_span, render_core_structural_element, render_core_table_cell, render_core_table_row, render_core_term, render_core_toc, render_core_toc_entry, resolve_block_semantic_type, resolve_format_specific_semantic, transform_to_coremodel, treat_children
Class Method Details
.to_coradoc(node, _state = {}) ⇒ Object
34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/coradoc/html/converters/block_image.rb', line 34 def self.to_coradoc(node, _state = {}) # Handle both <figure> and <div class="image"> cases if node.name == 'figure' img_node = node.at_css('img') return nil unless img_node attrs = extract_attributes(img_node) figcaption = node.at_css('figcaption') caption = figcaption&.text Coradoc::CoreModel::Image.new( src: attrs[:src], id: attrs[:id], caption: caption, alt: attrs[:alt], width: attrs[:width], height: attrs[:height], inline: false ) elsif node.name == 'div' && node['class'] == 'image' img_node = node.at_css('img') return nil unless img_node attrs = extract_attributes(img_node) Coradoc::CoreModel::Image.new( src: attrs[:src], id: attrs[:id], alt: attrs[:alt], width: attrs[:width], height: attrs[:height], inline: false ) end end |
.to_html(model, _state = {}) ⇒ Object
8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 |
# File 'lib/coradoc/html/converters/block_image.rb', line 8 def self.to_html(model, _state = {}) img_attrs = {} # Remove leading colons from src (source format syntax artifact) src = model.src src = src.sub(/^:+/, '') if src img_attrs[:src] = src if src img_attrs[:id] = model.id if model.id img_attrs[:alt] = model.alt || model.caption || '' # Extract additional attributes img_attrs[:width] = model.width if model.width img_attrs[:height] = model.height if model.height img_element = build_element('img', nil, img_attrs) # Wrap in figure if we have a caption if model.caption && !model.caption.empty? figcaption = build_element('figcaption', model.caption) content = "#{img_element}\n#{figcaption}" build_element('figure', "\n#{content}\n") else # Just a plain img element wrapped in a div for block display build_element('div', img_element, { class: 'image' }) end end |